@@ -11,14 +11,14 @@ skip_if_not_installed("RSQLite")
 # need to write bgen/bgi files because can't have binary files..
 library(magrittr)
 bgen_file <- tempfile(fileext = ".bgen")
-system.file("testdata", "bgen_example.rds", package = "bigsnpr") %>%
+test_path("testdata/bgen_example.rds") %>%
   readRDS() %>% writeBin(bgen_file, useBytes = TRUE)
-system.file("testdata", "bgi_example.rds",  package = "bigsnpr") %>%
+test_path("testdata/bgi_example.rds") %>%
   readRDS() %>% writeBin(paste0(bgen_file, ".bgi"), useBytes = TRUE)
 
-variants <- readRDS(system.file("testdata", "bgen_variants.rds", package = "bigsnpr"))
-dosages  <- readRDS(system.file("testdata", "bgen_dosages.rds",  package = "bigsnpr"))
-snp_info <- readRDS(system.file("testdata", "bgen_varinfo.rds",  package = "bigsnpr"))
+variants <- readRDS(test_path("testdata/bgen_variants.rds"))
+dosages  <- readRDS(test_path("testdata/bgen_dosages.rds"))
+snp_info <- readRDS(test_path("testdata/bgen_varinfo.rds"))
 IDs <- with(variants, paste(1, physical.pos, allele1, allele2, sep = "_"))
 # variants 18 & 19 have identical IDs
 excl <- c(18, 19)
@@ -27,6 +27,13 @@ ncores <- function() sample(1:2, 1)
 
 ################################################################################
 
+test_that("snp_readBGI() can return the full variant information", {
+  full_info <- snp_readBGI(paste0(bgen_file, ".bgi"))
+  expect_equal(full_info[c(1:2, 5:6)], variants[c(1, 4:6)], check.attributes = FALSE)
+})
+
+################################################################################
+
 test_that("raises some errors", {
   expect_error(snp_attach(snp_readBGEN(bgen_file, tempfile(), IDs, ncores = ncores())),
                "'list_snp_id' is not of class 'list'.", fixed = TRUE)
@@ -121,6 +128,7 @@ test_that("works with multiple files", {
 ################################################################################
 
 test_that("read as random hard calls", {
+  skip_on_covr()
   G <- snp_attach(snp_readBGEN(bgen_file, tempfile(), list(IDs)))$genotypes[]
   all_G <- replicate(50, simplify = FALSE, {
     test <- snp_readBGEN(bgen_file, tempfile(), list(IDs), read_as = "random")
@@ -137,3 +145,18 @@ test_that("read as random hard calls", {
 })
 
 ################################################################################
+
+test_that("work with duplicated variants or individuals", {
+  G <- snp_attach(snp_readBGEN(
+    bgen_file, tempfile(), list(rep("1_1001_A_G", 3))))$genotypes
+  expect_equal(ncol(G), 3)
+  expect_identical(G[, 1], G[, 2])
+  expect_identical(G[, 1], G[, 3])
+  G2 <- snp_attach(snp_readBGEN(
+    bgen_file, tempfile(), ind_row = rep(1, 3), list(IDs)))$genotypes
+  expect_equal(dim(G2), c(3, length(IDs)))
+  expect_identical(G2[1, ], G2[2, ])
+  expect_identical(G2[1, ], G2[3, ])
+})
+
+################################################################################
